@@ -1,26 +1,35 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
-
 import copy
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+)
+
+import numpy as np
+
+import boost_histogram
 
 from .._core import axis as ca
 from .axis_transform import AxisTransform
-from .deprecated import deprecated
-from .kwargs import KWArgs
-from .sig_tools import inject_signature
-from .six import string_types
 from .traits import Traits
-from .utils import MAIN_FAMILY, cast, register, set_family, set_module
-
-del absolute_import, division, print_function
+from .utils import cast, register, set_module
 
 
-def _isstr(value):
+def _isstr(value: Any) -> bool:
     """
     Check to see if this is a stringlike or a (nested) iterable of stringlikes
     """
 
-    if isinstance(value, string_types + (bytes,)):
+    if isinstance(value, (str, bytes)):
         return True
     elif hasattr(value, "__iter__"):
         return all(_isstr(v) for v in value)
@@ -28,26 +37,44 @@ def _isstr(value):
         return False
 
 
+def _opts(**kwargs: bool) -> Set[str]:
+    return {k for k, v in kwargs.items() if v}
+
+
+AxCallOrInt = Union[int, Callable[["Axis"], int]]
+
+
+T = TypeVar("T", bound="Axis")
+
+
 # Contains common methods and properties to all axes
 @set_module("boost_histogram.axis")
-class Axis(object):
+class Axis:
     __slots__ = ("_ax", "__dict__")
+    _family: object
 
-    def __setattr__(self, attr, value):
+    def __init_subclass__(cls, *, family: object) -> None:
+        super().__init_subclass__()
+        cls._family = family
+
+    def __setattr__(self, attr: str, value: Any) -> None:
         if attr == "__dict__":
             self._ax.metadata = value
         object.__setattr__(self, attr, value)
 
-    def __getattr__(self, attr):
+    def __getattr__(self, attr: str) -> Any:
         if attr == "metadata":
             return None
-        elif attr == "options":
-            return self._options()
         raise AttributeError(
-            "object {} has not attribute {}".format(self.__class__.__name__, attr)
+            f"object {self.__class__.__name__} has no attribute {attr}"
         )
 
-    def __init__(self, ax, metadata, __dict__):
+    def __init__(
+        self,
+        ax: Any,
+        metadata: Optional[Dict[str, Any]],
+        __dict__: Optional[Dict[str, Any]],
+    ) -> None:
         """
         ax: the C++ object
         metadata: the metadata keyword contents
@@ -67,26 +94,26 @@ class Axis(object):
 
         self.__dict__ = self._ax.metadata
 
-    def __setstate__(self, state):
+    def __setstate__(self, state: Dict[str, Any]) -> None:
         self._ax = state["_ax"]
         self.__dict__ = self._ax.metadata
 
-    def __getstate__(self):
+    def __getstate__(self) -> Dict[str, Any]:
         return {"_ax": self._ax}
 
-    def __copy__(self):
-        other = self.__class__.__new__(self.__class__)
+    def __copy__(self: T) -> T:
+        other: T = self.__class__.__new__(self.__class__)
         other._ax = copy.copy(self._ax)
         other.__dict__ = other._ax.metadata
         return other
 
-    def index(self, value):
+    def index(self, value: Union[float, str]) -> int:
         """
         Return the fractional index(es) given a value (or values) on the axis.
         """
 
         if not _isstr(value):
-            return self._ax.index(value)
+            return self._ax.index(value)  # type: ignore
         else:
             raise TypeError(
                 "index({value}) cannot be a string for a numerical axis".format(
@@ -94,96 +121,89 @@ class Axis(object):
                 )
             )
 
-    def value(self, index):
+    def value(self, index: float) -> float:
         """
         Return the value(s) given an (fractional) index (or indices).
         """
 
-        return self._ax.value(index)
+        return self._ax.value(index)  # type: ignore
 
-    def bin(self, index):
+    def bin(self, index: float) -> Union[int, str, Tuple[float, float]]:
         """
         Return the edges of the bins as a tuple for a
         continuous axis or the bin value for a
         non-continuous axis, when given an index.
         """
 
-        return self._ax.bin(index)
+        return self._ax.bin(index)  # type: ignore
 
-    def __eq__(self, other):
-        return self._ax == other._ax
+    def __eq__(self, other: Any) -> bool:
+        return self._ax == other._ax  # type: ignore
 
-    def __ne__(self, other):
-        return self._ax != other._ax
+    def __ne__(self, other: Any) -> bool:
+        return self._ax != other._ax  # type: ignore
 
     @classmethod
-    def _convert_cpp(cls, cpp_object):
-        nice_ax = cls.__new__(cls)
+    def _convert_cpp(cls: Type[T], cpp_object: Any) -> T:
+        nice_ax: T = cls.__new__(cls)
         nice_ax._ax = cpp_object
         nice_ax.__dict__ = cpp_object.metadata
         return nice_ax
 
-    def __len__(self):
-        return self._ax.size
+    def __len__(self) -> int:
+        return self._ax.size  # type: ignore
 
-    def __iter__(self):
-        return self._ax.__iter__()
+    def __iter__(
+        self,
+    ) -> Union[Iterator[float], Iterator[str], Iterator[Tuple[float, float]]]:
+        return self._ax.__iter__()  # type: ignore
 
-    def _process_loc(self, start, stop):
+    def _process_loc(
+        self, start: Optional[AxCallOrInt], stop: Optional[AxCallOrInt]
+    ) -> Tuple[int, int]:
         """
         Compute start and stop into actual start and stop values in Boost.Histogram.
         None -> -1 or 0 for start, -> len or len+1 for stop. If start or stop are
         callable, then call them with the axes.
+
+        For a non-ordered axes, flow is all or nothing, so this will ensure overflow
+        is turned off if underflow is not None.
         """
 
-        def _process_internal(item, default):
+        def _process_internal(item: Optional[AxCallOrInt], default: int) -> int:
             return default if item is None else item(self) if callable(item) else item
 
-        begin = _process_internal(start, -1 if self._ax.traits_underflow else 0)
-        end = _process_internal(
-            stop, len(self) + (1 if self._ax.traits_overflow else 0)
-        )
+        underflow = -1 if self._ax.traits_underflow else 0
+        overflow = 1 if self._ax.traits_overflow else 0
+
+        # Non-ordered axes only use flow if integrating from None to None
+        if not self._ax.traits_ordered and not (start is None and stop is None):
+            overflow = 0
+
+        begin = _process_internal(start, underflow)
+        end = _process_internal(stop, len(self) + overflow)
 
         return begin, end
 
-    def __repr__(self):
-        return "{self.__class__.__name__}({args}{kwargs})".format(
-            self=self, args=self._repr_args(), kwargs=self._repr_kwargs()
-        )
+    def __repr__(self) -> str:
+        arg_str = ", ".join(self._repr_args_())
+        return f"{self.__class__.__name__}({arg_str})"
 
-    def _repr_kwargs(self):
+    def _repr_args_(self) -> List[str]:
         """
-        Return options for use in repr. Metadata is last,
-        just in case it spans multiple lines.
+        Return arg options for use in the repr as strings.
         """
 
-        ret = ""
-        if self.traits.growth:
-            ret += ", growth=True"
-        elif self.traits.circular:
-            ret += ", circular=True"
-        else:
-            if not self.traits.underflow:
-                ret += ", underflow=False"
-            if not self.traits.overflow:
-                ret += ", overflow=False"
-
+        ret = []
+        if self.metadata is not None:
+            if isinstance(self.metadata, str):
+                ret.append(f"metadata={self.metadata!r}")
+            else:
+                ret.append("metadata=...")
         return ret
 
-    @deprecated("Use .traits instead", name="options")
-    def _options(self):
-        """
-        Return the options.  Fields:
-          .underflow - True if axes captures values that are too small
-          .overflow  - True if axes captures values that are too large
-                       (or non-valid for category axes)
-          .growth    - True if axis can grow
-          .circular  - True if axis wraps around
-        """
-        return self._ax.options
-
     @property
-    def traits(self):
+    def traits(self) -> Traits:
         """
         Get traits for the axis - read only properties of a specific axis.
         """
@@ -197,20 +217,20 @@ class Axis(object):
         )
 
     @property
-    def size(self):
+    def size(self) -> int:
         """
         Return number of bins excluding under- and overflow.
         """
-        return self._ax.size
+        return self._ax.size  # type: ignore
 
     @property
-    def extent(self):
+    def extent(self) -> int:
         """
         Return number of bins including under- and overflow.
         """
-        return self._ax.extent
+        return self._ax.extent  # type: ignore
 
-    def __getitem__(self, i):
+    def __getitem__(self, i: AxCallOrInt) -> Union[int, str, Tuple[float, float]]:
         """
         Access a bin, using normal Python syntax for wraparound.
         """
@@ -222,27 +242,28 @@ class Axis(object):
                 i += self._ax.size
             if i >= self._ax.size:
                 raise IndexError(
-                    "Out of range access, {} is more than {}".format(i, self._ax.size)
+                    f"Out of range access, {i} is more than {self._ax.size}"
                 )
+        assert not callable(i)
         return self.bin(i)
 
     @property
-    def edges(self):
-        return self._ax.edges
+    def edges(self) -> np.ndarray:
+        return self._ax.edges  # type: ignore
 
     @property
-    def centers(self):
+    def centers(self) -> np.ndarray:
         """
         An array of bin centers.
         """
-        return self._ax.centers
+        return self._ax.centers  # type: ignore
 
     @property
-    def widths(self):
+    def widths(self) -> np.ndarray:
         """
         An array of bin widths.
         """
-        return self._ax.widths
+        return self._ax.widths  # type: ignore
 
 
 # Contains all common methods and properties for Regular axes
@@ -260,14 +281,23 @@ class Axis(object):
     }
 )
 @set_module("boost_histogram.axis")
-@set_family(MAIN_FAMILY)
-class Regular(Axis):
+class Regular(Axis, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature(
-        "self, bins, start, stop, *, metadata=None, underflow=True, overflow=True, growth=False, circular=False, transform=None, __dict__=None"
-    )
-    def __init__(self, bins, start, stop, **kwargs):
+    def __init__(
+        self,
+        bins: int,
+        start: float,
+        stop: float,
+        *,
+        metadata: Any = None,
+        underflow: bool = True,
+        overflow: bool = True,
+        growth: bool = False,
+        circular: bool = False,
+        transform: Optional[AxisTransform] = None,
+        __dict__: Optional[Dict[str, Any]] = None,
+    ):
         """
         Make a regular axis with nice keyword arguments for underflow,
         overflow, and growth.
@@ -297,13 +327,11 @@ class Regular(Axis):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            transform = k.optional("transform")
-            __dict__ = k.optional("__dict__")
-            options = k.options(
-                underflow=True, overflow=True, growth=False, circular=False
-            )
+        options = _opts(
+            underflow=underflow, overflow=overflow, growth=growth, circular=circular
+        )
+
+        ax: "ca._BaseRegular"
 
         if transform is not None:
             if options != {"underflow", "overflow"}:
@@ -313,7 +341,7 @@ class Regular(Axis):
                 not isinstance(transform, AxisTransform)
                 and AxisTransform in transform.__bases__
             ):
-                raise TypeError("You must pass an instance, use {}()".format(transform))
+                raise TypeError(f"You must pass an instance, use {transform}()")
 
             ax = transform._produce(bins, start, stop)
 
@@ -325,10 +353,13 @@ class Regular(Axis):
             ax = ca.regular_uflow(bins, start, stop)
         elif options == {"overflow"}:
             ax = ca.regular_oflow(bins, start, stop)
-        elif options == {"circular", "underflow", "overflow"} or options == {
-            "circular",
-            "overflow",
-        }:
+        elif options in [
+            {"circular", "underflow", "overflow"},
+            {
+                "circular",
+                "overflow",
+            },
+        ]:
             # growth=True, underflow=False is also correct
             ax = ca.regular_circular(bins, start, stop)
 
@@ -337,25 +368,32 @@ class Regular(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-        super(Regular, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        return "{bins:g}, {start:g}, {stop:g}".format(
-            bins=self.size, start=self.edges[0], stop=self.edges[-1]
-        )
+        ret = [f"{self.size:g}", f"{self.edges[0]:g}", f"{self.edges[-1]:g}"]
 
-    def _repr_kwargs(self):
-        ret = super(Regular, self)._repr_kwargs()
+        if self.traits.growth:
+            ret.append("growth=True")
+        elif self.traits.circular:
+            ret.append("circular=True")
+        else:
+            if not self.traits.underflow:
+                ret.append("underflow=False")
+            if not self.traits.overflow:
+                ret.append("overflow=False")
 
         if self.transform is not None:
-            ret += ", transform={}".format(self.transform)
+            ret.append(f"transform={self.transform}")
+
+        ret += super()._repr_args_()
 
         return ret
 
     @property
-    def transform(self):
+    def transform(self) -> Optional[AxisTransform]:
         if hasattr(self._ax, "transform"):
             return cast(self, self._ax.transform, AxisTransform)
         return None
@@ -371,15 +409,21 @@ class Regular(Axis):
         ca.variable_circular,
     }
 )
-@set_family(MAIN_FAMILY)
 @set_module("boost_histogram.axis")
-class Variable(Axis):
+class Variable(Axis, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature(
-        "self, edges, *, metadata=None, underflow=True, overflow=True, growth=False, __dict__=None"
-    )
-    def __init__(self, edges, **kwargs):
+    def __init__(
+        self,
+        edges: Iterable[float],
+        *,
+        metadata: Any = None,
+        underflow: bool = True,
+        overflow: bool = True,
+        growth: bool = False,
+        circular: bool = False,
+        __dict__: Optional[Dict[str, Any]] = None,
+    ):
         """
         Make an axis with irregularly spaced bins. Provide a list
         or array of bin edges, and len(edges)-1 bins will be made.
@@ -403,13 +447,11 @@ class Variable(Axis):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            __dict__ = k.optional("__dict__")
-            options = k.options(
-                underflow=True, overflow=True, circular=False, growth=False
-            )
+        options = _opts(
+            underflow=underflow, overflow=overflow, growth=growth, circular=circular
+        )
 
+        ax: "ca._BaseVariable"
         if options == {"growth", "underflow", "overflow"}:
             ax = ca.variable_uoflow_growth(edges)
         elif options == {"underflow", "overflow"}:
@@ -418,10 +460,17 @@ class Variable(Axis):
             ax = ca.variable_uflow(edges)
         elif options == {"overflow"}:
             ax = ca.variable_oflow(edges)
-        elif options == {"circular", "underflow", "overflow",} or options == {
-            "circular",
-            "overflow",
-        }:
+        elif options in [
+            {
+                "circular",
+                "underflow",
+                "overflow",
+            },
+            {
+                "circular",
+                "overflow",
+            },
+        ]:
             # growth=True, underflow=False is also correct
             ax = ca.variable_circular(edges)
         elif options == set():
@@ -429,15 +478,29 @@ class Variable(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-        super(Variable, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
         if len(self) > 20:
-            return repr(self.edges)
+            ret = [repr(self.edges)]
         else:
-            return "[{}]".format(", ".join(format(v, "g") for v in self.edges))
+            ret = ["[{}]".format(", ".join(format(v, "g") for v in self.edges))]
+
+        if self.traits.growth:
+            ret.append("growth=True")
+        elif self.traits.circular:
+            ret.append("circular=True")
+        else:
+            if not self.traits.underflow:
+                ret.append("underflow=False")
+            if not self.traits.overflow:
+                ret.append("overflow=False")
+
+        ret += super()._repr_args_()
+
+        return ret
 
 
 @register(
@@ -450,15 +513,22 @@ class Variable(Axis):
         ca.integer_circular,
     }
 )
-@set_family(MAIN_FAMILY)
 @set_module("boost_histogram.axis")
-class Integer(Axis):
+class Integer(Axis, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature(
-        "self, start, stop, *, metadata=None, underflow=True, overflow=True, growth=False, __dict__=None"
-    )
-    def __init__(self, start, stop, **kwargs):
+    def __init__(
+        self,
+        start: int,
+        stop: int,
+        *,
+        metadata: Any = None,
+        underflow: bool = True,
+        overflow: bool = True,
+        growth: bool = False,
+        circular: bool = False,
+        __dict__: Optional[Dict[str, Any]] = None,
+    ):
         """
         Make an integer axis, with a collection of consecutive integers.
 
@@ -483,12 +553,11 @@ class Integer(Axis):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            __dict__ = k.optional("__dict__")
-            options = k.options(
-                underflow=True, overflow=True, circular=False, growth=False
-            )
+        options = _opts(
+            underflow=underflow, overflow=overflow, growth=growth, circular=circular
+        )
+
+        ax: "ca._BaseInteger"
 
         # underflow and overflow settings are ignored, integers are always
         # finite and thus cannot end up in a flow bin when growth is on
@@ -507,44 +576,58 @@ class Integer(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-        super(Integer, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        return "{start:g}, {stop:g}".format(start=self.edges[0], stop=self.edges[-1])
+        ret = [f"{self.edges[0]:g}", f"{self.edges[-1]:g}"]
 
-
-class BaseCategory(Axis):
-    __slots__ = ()
-
-    def _repr_kwargs(self):
-        """
-        Return options for use in repr. Metadata is last,
-        just in case it spans multiple lines.
-
-
-        This is specialized for Category axes to avoid repeating
-        the flow arguments unnecessarily.
-        """
-
-        ret = ""
         if self.traits.growth:
-            ret += ", growth=True"
+            ret.append("growth=True")
         elif self.traits.circular:
-            ret += ", circular=True"
+            ret.append("circular=True")
+        else:
+            if not self.traits.underflow:
+                ret.append("underflow=False")
+            if not self.traits.overflow:
+                ret.append("overflow=False")
+
+        ret += super()._repr_args_()
 
         return ret
 
 
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-@register({ca.category_str_growth, ca.category_str})
-class StrCategory(BaseCategory):
+class BaseCategory(Axis, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature("self, categories, *, metadata=None, growth=False, __dict__=None")
-    def __init__(self, categories, **kwargs):
+    def _repr_args_(self) -> List[str]:
+        "Return inner part of signature for use in repr"
+
+        ret = []
+
+        if self.traits.growth:
+            ret.append("growth=True")
+        elif self.traits.circular:
+            ret.append("circular=True")
+
+        ret += super()._repr_args_()
+        return ret
+
+
+@set_module("boost_histogram.axis")
+@register({ca.category_str_growth, ca.category_str})
+class StrCategory(BaseCategory, family=boost_histogram):
+    __slots__ = ()
+
+    def __init__(
+        self,
+        categories: Iterable[str],
+        *,
+        metadata: Any = None,
+        growth: bool = False,
+        __dict__: Optional[Dict[str, Any]] = None,
+    ):
         """
         Make a category axis with strings; items will
         be added to a predefined list of bins or a growing (with growth=True)
@@ -564,10 +647,9 @@ class StrCategory(BaseCategory):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            __dict__ = k.optional("__dict__")
-            options = k.options(growth=False)
+        options = _opts(growth=growth)
+
+        ax: "ca._BaseCatStr"
 
         # henryiii: We currently expand "abc" to "a", "b", "c" - some
         # Python interfaces protect against that
@@ -579,15 +661,15 @@ class StrCategory(BaseCategory):
         else:
             raise KeyError("Unsupported collection of options")
 
-        super(StrCategory, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def index(self, value):
+    def index(self, value: Union[float, str]) -> int:
         """
         Return the fractional index(es) given a value (or values) on the axis.
         """
 
         if _isstr(value):
-            return self._ax.index(value)
+            return self._ax.index(value)  # type: ignore
         else:
             raise TypeError(
                 "index({value}) must be a string or iterable of strings for a StrCategory axis".format(
@@ -595,20 +677,27 @@ class StrCategory(BaseCategory):
                 )
             )
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        return "[{}]".format(", ".join(repr(c) for c in self))
+        ret = ["[{}]".format(", ".join(repr(c) for c in self))]
+        ret += super()._repr_args_()
+        return ret
 
 
-@set_family(MAIN_FAMILY)
 @set_module("boost_histogram.axis")
 @register({ca.category_int, ca.category_int_growth})
-class IntCategory(BaseCategory):
+class IntCategory(BaseCategory, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature("self, categories, *, metadata=None, growth=False, __dict__=None")
-    def __init__(self, categories, **kwargs):
+    def __init__(
+        self,
+        categories: Iterable[int],
+        *,
+        metadata: Any = None,
+        growth: bool = False,
+        __dict__: Optional[Dict[str, Any]] = None,
+    ):
         """
         Make a category axis with ints; items will
         be added to a predefined list of bins or a growing (with growth=True)
@@ -628,10 +717,8 @@ class IntCategory(BaseCategory):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            __dict__ = k.optional("__dict__")
-            options = k.options(growth=False)
+        options = _opts(growth=growth)
+        ax: "ca._BaseCatInt"
 
         if options == {"growth"}:
             ax = ca.category_int_growth(tuple(categories))
@@ -640,23 +727,25 @@ class IntCategory(BaseCategory):
         else:
             raise KeyError("Unsupported collection of options")
 
-        super(IntCategory, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
 
-        return "[{}]".format(", ".join(format(c, "g") for c in self))
+        ret = ["[{}]".format(", ".join(format(c, "g") for c in self))]
+        ret += super()._repr_args_()
+        return ret
 
 
 # Contains all common methods and properties for the boolean axis
 @register({ca.boolean})
-@set_family(MAIN_FAMILY)
 @set_module("boost_histogram.axis")
-class Boolean(Axis):
+class Boolean(Axis, family=boost_histogram):
     __slots__ = ()
 
-    @inject_signature("self, *, metadata=None, __dict__=None")
-    def __init__(self, **kwargs):
+    def __init__(
+        self, *, metadata: Any = None, __dict__: Optional[Dict[str, Any]] = None
+    ):
         """
         Make an axis for boolean values.
 
@@ -668,32 +757,20 @@ class Boolean(Axis):
             The full metadata dictionary
         """
 
-        with KWArgs(kwargs) as k:
-            metadata = k.optional("metadata")
-            __dict__ = k.optional("__dict__")
-
         ax = ca.boolean()
 
-        super(Boolean, self).__init__(ax, metadata, __dict__)
+        super().__init__(ax, metadata, __dict__)
 
-    def _repr_args(self):
+    def _repr_args_(self) -> List[str]:
         "Return inner part of signature for use in repr"
-        if self.size == 2:
-            return ""
-        elif self.size == 0:
-            return "<empty>"
+        ret = []
+
+        if self.size == 0:
+            ret.append("<empty>")
         elif self.size == 1 and self.centers[0] < 0.75:
-            return "<False>"
+            ret.append("<False>")
         elif self.size == 1:
-            return "<True>"
-        else:
-            # Shouldn't be possible, can't grow
-            "<unknown>"
+            ret.append("<True>")
 
-    def _repr_kwargs(self):
-        """
-        Return options for use in repr. Metadata is last,
-        just in case it spans multiple lines.
-        """
-
-        return ""
+        ret += super()._repr_args_()
+        return ret
